#define _XOPEN_SOURCE 500
#include <ftw.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <stdint.h>
#include <assert.h>

void error_fatal (char *message){
  perror (message);
  exit (EXIT_FAILURE);
}

static int display_info (const char *fpath, const struct stat *sb,
			 int tflag, struct FTW *ftwbuf){
  /* Provera da li je string dovoljno dugacak da u njega stane string "Makefile", tj. da li ima bar 9 karaktera
     (potrebno je da ima string "Makefile" i bar jedan dodatan karakter koji oznacava direktorijum.
     Zaobilaze se fajlovi koji pre slova M nemaju '/' jer ime fajla moze biti npr. "backupMakefile"*/
  if (strlen (fpath) >= 9 && 
      strcmp (fpath + strlen(fpath) - 8, "Makefile") == 0 &&
      fpath [strlen (fpath)-9] == '/')
    printf ("%-40s %jd\n", fpath, (intmax_t) sb->st_size);
  return 0;			/* To tell nftw() to continue */
}

int
main (int argc, char *argv[]){
  int flags = 0;
  struct stat fajl_podaci;

  assert (argc == 2);

  if (lstat (argv[1], &fajl_podaci) < 0)
    error_fatal ("lstat error");

  /* Ukoliko fajl nije direktorijum prekida se program. */
  if (!S_ISDIR (fajl_podaci.st_mode))
    error_fatal ("Not a directory!");

  if (nftw (argv[1], display_info, 20, flags) == -1){
      perror ("nftw");
      exit (EXIT_FAILURE);
  }

  exit (EXIT_SUCCESS);
}
